@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2001 Misha Nasledov <misha@nasledov.com>
+ * Copyright (C) 2000-2002 Misha Nasledov <misha@nasledov.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -44,6 +44,7 @@
 #include "tasks.h"
 #include "rcv.h"
 #include "connect.h"
+#include "log.h"
 
 #include "pixmaps/msg.xpm"
 #include "pixmaps/chat.xpm"
@@ -346,6 +347,38 @@ static void xoutput_chat (session *sess, guint32 cid, char *chat)
 		return;
 	}
 
+#if 0
+	if(gtkhx_prefs.logging) {
+		if(!server_log) {
+			/* XXX: open it up here */
+#warning FIXME
+		}
+		
+		
+		if(cid == 0 && server_log) {
+			char *copy = g_strdup(chat);
+			int len = strlen(chat);
+			
+			if(len > 18 && !strncmp(INFOPREFIX, copy, 18)) {
+				memmove(&copy[7], &copy[18], len-17);
+				sprintf(copy, " [hx] %s", &copy[7]);
+				len = strlen(copy);
+			}
+			if(gtkhx_prefs.timestamp) {
+				char *new_text = g_malloc0(len+12);
+				timecpy(new_text);
+				memcpy(new_text +11, copy, len);
+				print_log(server_log, new_text);
+				g_free(new_text);
+			}
+			else {
+				print_log(server_log, copy);
+			}
+			g_free(copy);
+		}
+	}
+#endif
+
 	cr = strchr(chat, '\n');
 	if(cr) {
 		while(1) {
