@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2001 Misha Nasledov <misha@nasledov.com>
+ * Copyright (C) 2000-2002 Misha Nasledov <misha@nasledov.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -45,7 +45,11 @@ static GtkWidget *cipher_menu;
 #if defined(CONFIG_CIPHER)
 
 #define DEFAULT_CIPHER "BLOWFISH"
-char *valid_ciphers[] = {"RC4", "BLOWFISH", "IDEA", 0};
+char *valid_ciphers[] = {"RC4", "BLOWFISH", 
+#ifndef CONFIG_NO_IDEA
+"IDEA", 
+#endif
+0};
 
 int valid_cipher (const char *cipheralg)
 {
@@ -154,6 +158,10 @@ static void server_connect (GtkWidget *widget, gpointer data)
 				memset(sess->htlc.compressalg, 0, sizeof(sess->htlc.compressalg));
 			}
 		}
+		else {
+			memset(sess->htlc.compressalg, 0, sizeof(sess->htlc.compressalg));
+		}
+
 #endif
 #ifdef CONFIG_CIPHER
 		if(cipher) {
@@ -167,6 +175,9 @@ static void server_connect (GtkWidget *widget, gpointer data)
 				memset(sess->htlc.cipheralg, 0, sizeof(sess->htlc.cipheralg));
 			}
 		}
+		else {
+			memset(sess->htlc.cipheralg, 0, sizeof(sess->htlc.cipheralg));
+		}
 #endif
 	}
 
@@ -662,8 +673,8 @@ void select_cipher(GtkWidget *compress_item, gpointer data)
 	int i = GPOINTER_TO_INT(data);
 
 //	if(i >= 0 && valid_ciphers[i-1]) {
-		gtk_object_remove_data(GTK_OBJECT(cipher_menu), "cipher");
-		gtk_object_set_data(GTK_OBJECT(cipher_menu), "cipher", GINT_TO_POINTER(i));
+	gtk_object_remove_data(GTK_OBJECT(cipher_menu), "cipher");
+	gtk_object_set_data(GTK_OBJECT(cipher_menu), "cipher", GINT_TO_POINTER(i));
 //	}
 }
 #endif
