@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2001 Misha Nasledov <misha@nasledov.com>
+ * Copyright (C) 2000-2002 Misha Nasledov <misha@nasledov.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -56,6 +56,7 @@
 #include "plugin.h"
 #include "commands.h"
 #include "getopt.h"
+#include "log.h"
 
 char last_msg_nick[32];
 char *g_user_colors[4] = {WHITE_BOLD, WHITE, RED_BOLD, RED};
@@ -74,7 +75,7 @@ static struct timer *timer_list;
 static int rinput_tags[1024];
 static int winput_tags[1024];
 
-const char *INFOPREFIX = " \00310[\003\00303hx\003\00310]\003 ";
+const char *INFOPREFIX = " \00310[\00303hx\00310]\003 ";
 
 session sessions[MAX_CONN];
 
@@ -88,6 +89,10 @@ void hx_quit (void)
 		hx_htlc_close(&sessions[0].htlc, 1);
 	}
 
+#if 0 /* XXX */
+	close_logs();
+#endif
+
 	gtk_thread_exit();
 	gtk_main_quit();
 	exit(0);
@@ -400,16 +405,24 @@ static void output_user_info (guint16 uid, const char *nam, const char *info,
 	if(len > 0) {
 		GtkWidget *info_window;
 		GtkWidget *info_text;
+		GtkWidget *vscroll;
+		GtkWidget *hbox;
 		char infotitle[45];
 
 		info_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-		gtk_widget_set_usize(info_window, 256, 0);
+		gtk_widget_set_usize(info_window, 260, 250);
 
-		sprintf(infotitle, "%s: %s (%u)", _("User Info"), nam, uid);
+		sprintf(infotitle, _("User Info: %s (%u)"), nam, uid);
 		gtk_window_set_title(GTK_WINDOW(info_window), infotitle);
 
+		hbox = gtk_hbox_new(0, 0);
 		info_text = gtk_text_new(0, 0);
-		gtk_container_add(GTK_CONTAINER(info_window), info_text);
+		vscroll = gtk_vscrollbar_new(GTK_TEXT(info_text)->vadj);
+
+		gtk_box_pack_start(GTK_BOX(hbox), info_text, 1, 1, 0);
+		gtk_box_pack_start(GTK_BOX(hbox), vscroll, 0, 0, 0);
+
+		gtk_container_add(GTK_CONTAINER(info_window), hbox);
 		gtk_text_insert(GTK_TEXT(info_text), 0, 0, 0, info, len);
 		init_keyaccel(info_window);
 		gtk_widget_show_all(info_window);
@@ -634,6 +647,47 @@ main (int argc, char **argv, char **envp)
 	return 0;
 }
 
+char *hxd_commands[] = {
+	"0wn",
+	"access",
+	"away",
+	"alert",
+	"broadcast",
+	"color",
+	"exec",
+	"g0away",
+	"maltbl",
+	"mon",
+	"users",
+	"version",
+	"visible",
+};
+
+int hxdcmd_len = sizeof(hxd_commands)/sizeof(hxd_commands[0]);
+
+int is_hxdcmd(char *str)
+{
+	int i;
+	char *ptr;
+
+	if(!str) {
+		return 0;
+	}
+
+	ptr = strchr(str, ' ');
+
+	for(i = 0; i < hxdcmd_len; i++) {
+		int _len = strlen(hxd_commands[i]);
+		int len = ptr-str>_len?_len:ptr-str;
+
+		if(!strncmp(hxd_commands[i], str, len)) {
+			return 1;
+		} 
+	}
+
+	return 0;
+}
+
 void
 hotline_client_input (struct htlc_conn *htlc, char *str, guint32 cid, 
 					  guint16 style)
@@ -647,10 +701,16 @@ hotline_client_input (struct htlc_conn *htlc, char *str, guint32 cid,
 #endif
 
 		if (*str == '/' && *++str && *str != '/') {
+			if(is_hxdcmd(str)) {
+				str--;
+				hx_send_chat(htlc, str, cid, style);
+			}
+			else {
 				hx_command(str, cid);
+			}
 		}
 		else {
-				hx_send_chat(htlc, str, cid, style);
+			hx_send_chat(htlc, str, cid, style);
 		}
 	}
 }
@@ -685,20 +745,21 @@ void get_password(char *buf)
 
 void print_help (char *name)
 {
-	printf("GtkHx %s, Copyright (C) 2001 Misha Nasledov\n", VERSION);
-	printf("GtkHx comes with ABSOLUTELY NO WARRANTY.\n");
-	printf("This is free software, and you are welcome\n");
-	printf("to redistribute it under certain conditions.\n\n");
-
-	printf("usage: %s [options]\n", name);
-	printf("\nsupported options:\n");
-	printf("\t--help, -h\t\tPrint this help message out.\n");
-	printf("\t--server, -s <host>\tConnect to <host>\n");
-	printf("\t--port, -t <port>\tConnect to <host> on <port>. (default: 5500)"
-		   "\n");
-	printf("\t--login, -l <login>\tUse <login> for <host>. (default: guest)\n");
-	printf("\t--pass, -p\t\tPrompt for pass of <login>.\n");
-	printf("\t--bookmark, -b <name>\tConnect using bookmark <name>.\n");
+	printf(_("GtkHx %s, Copyright (C) 2000-2002 Misha Nasledov\n"), VERSION);
+	printf(_("GtkHx comes with ABSOLUTELY NO WARRANTY.\n"));
+	printf(_("This is free software, and you are welcome\n"));
+	printf(_("to redistribute it under certain conditions.\n\n"));
+	
+	printf(_("usage: %s [options]\n"), name);
+	printf(_("\nsupported options:\n"));
+	printf(_("\t--help, -h\t\tPrint this help message out.\n"));
+	printf(_("\t--server, -s <host>\tConnect to <host>\n"));
+	printf(_("\t--port, -t <port>\tConnect to <host> on <port>. "
+			 "(default: 5500)\n"));
+	printf(_("\t--login, -l <login>\tUse <login> for <host>. "
+			 "(default: guest)\n"));
+    printf(_("\t--pass, -p\t\tPrompt for pass of <login>.\n"));
+    printf(_("\t--bookmark, -b <name>\tConnect using bookmark <name>.\n"));
 }
 
 static struct option hx_options[] = {
