@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2001 Misha Nasledov <misha@nasledov.com>
+ * Copyright (C) 2000-2002 Misha Nasledov <misha@nasledov.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -51,6 +51,7 @@
 #include "tasks.h"
 #include "users.h"
 #include "inet.h"
+#include "log.h"
 
 #include "sha.h"
 #include "md5.h"
@@ -60,6 +61,10 @@ char *server_addr;
 guint16 server_port;
 #endif
 
+#if 0 /* XXX */
+struct log *server_log = NULL;
+#endif
+
 #ifndef WIN32
 pthread_t conn_tid;
 #else
@@ -218,6 +223,14 @@ hx_htlc_close (struct htlc_conn *htlc, int expected)
 #endif
 	memset(htlc->sessionkey, 0, sizeof(htlc->sessionkey));
 	htlc->sklen = 0;
+
+#if 0 /* XXX */
+	close_log(server_log);
+	server_log = NULL;
+#endif
+
+	g_free(server_addr);
+	server_addr = NULL;
 }
 unsigned int
 decode (struct htlc_conn *htlc)
@@ -455,7 +468,6 @@ static void hx_thread_connect (void *arg)
 #endif
 	
 	htlc->gdk_input = 0;
-	server_addr = g_strdup_printf("%s:%u", serverstr, port);
 
 	debug("entering gtk_threads\n");
 	gtk_threads_enter();
@@ -803,7 +815,7 @@ static void hx_thread_connect (void *arg)
 	g_free(cdata->pass);
 	g_free(cdata->serverstr);
 	g_free(cdata);
-
+	
 	conn_tid = 0;
 	pthread_exit(0);
 }
@@ -829,6 +841,12 @@ void hx_connect(struct htlc_conn *htlc, const char *serverstr, guint16 port,
 	}
 	hx_clear_chat(htlc, 0, 1);
 
+	server_addr = g_strdup_printf("%s:%u", serverstr, port);
+
+#if 0 /* XXX */
+	server_log = create_log(server_addr);
+#endif
+
 	cdata = g_malloc(sizeof(struct connect_data));
 	cdata->htlc = htlc;
 	cdata->serverstr = g_strdup(serverstr);
@@ -1030,6 +1048,7 @@ void hx_tracker_list(session *sess, char *serverstr, guint16 port)
 	if (write(s, HTRK_MAGIC, HTRK_MAGIC_LEN) != HTRK_MAGIC_LEN)
 		goto funk_dat;
 
+	track_prog_update(sess, serverstr, 0, 0);
 
 	if (b_read(s, buf, 14) != 14) {
 		goto funk_dat;
@@ -1038,6 +1057,7 @@ void hx_tracker_list(session *sess, char *serverstr, guint16 port)
 
 	nservers = ntohs(*((guint16 *)(&(buf[10]))));
 	total = nservers;
+	track_prog_update(sess, serverstr, 0, total);
 	for (i = 1; nservers; nservers--, i++) {
 		if (b_read(s, buf, 8) == -1) {
 			break;
