@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2001 Misha Nasledov <misha@nasledov.com>
+ * Copyright (C) 2000-2002 Misha Nasledov <misha@nasledov.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -1204,6 +1204,8 @@ static time_t date_to_unix (struct date_time *dt)
 			the actual date ... quite odd */
 		 timetm.tm_sec = dt->seconds+(24*3600);
 		 timetm.tm_year = (dt->base_year-1900);
+		 if(timetm.tm_year < 0)
+			 timetm.tm_year = 1970;
 		 timet =  mktime(&timetm);	
 		 return timet;
 	}
@@ -1227,7 +1229,7 @@ void output_news_thread(struct news_post *post)
 	}
 	
 	timet = date_to_unix(&item->date);
-	
+		
 	gtk_editable_delete_text(GTK_EDITABLE(gcnews->news_text), 0, -1);
 
 	if (item) {
